@@ -2,7 +2,7 @@
 # Author: Yi Wang 
 # 05-Jan-2010
 
-# last modifed: David Warton, 06-May-2015
+# last modifed: David Warton, 10-Apr-2019
 
 default.print.anova.manyglm <- function(x,
         digits = max(getOption("digits") - 3, 3),
@@ -12,7 +12,7 @@ default.print.anova.manyglm <- function(x,
    allargs <- match.call(expand.dots=FALSE)
    dots <- allargs$...
         
-    anova   <- x
+   anova   <- x
     x       <- anova$table
     if (!is.logical(signif.stars) || is.na(signif.stars)) {
         warning("option \"show.signif.stars\" is invalid: assuming TRUE")
@@ -49,7 +49,6 @@ default.print.anova.manyglm <- function(x,
         cat(heading, sep = "\n")
     if (!is.null(title <- attr(x, "title")))    
         cat(title)   else cat("\n")
-
     nc <- dim(x)[2]
     if (is.null(cn <- colnames(x))) 
         stop("anova table must have colnames")
@@ -83,14 +82,14 @@ default.print.anova.manyglm <- function(x,
          if(dim(anova$uni.p)[2]>1)
          {   
            cat("Arguments:\n", "Test statistics calculated assuming", corname, 
-               "\n P-value calculated using", n.bootsdone, "resampling iterations via",       paste(anova$resamp,block.text,sep=""), "resampling (to account for correlation in testing).\n")
+               "\n P-value calculated using", n.bootsdone, "iterations via",       paste(anova$resamp,block.text,sep=""), "resampling.\n")
          }
          if(dim(anova$uni.p)[2]==1)
          {   
-           cat("Arguments: P-value calculated using", n.bootsdone, "resampling iterations via",       paste(anova$resamp,block.text,sep=""), "resampling (to account for correlation in testing).\n")
+           cat("Arguments: P-value calculated using", n.bootsdone, "iterations via",       paste(anova$resamp,block.text,sep=""), "resampling.\n")
          }
 #         cat("Arguments:\n", "Test statistics calculated assuming", corname, 
-#              "\n P-value calculated using", n.bootsdone, "resampling iterations via",       paste(anova$resamp,block.text,sep=""), "resampling (to account for correlation in testing).\n")
+#              "\n P-value calculated using", n.bootsdone, "iterations via",       paste(anova$resamp,block.text,sep=""), "resampling.\n")
                 if(sum(anova$nBoot - anova$n.bootsdone)>1){
                     cat("\nNumber of iterations with skipped test statistic as the respective variable/variable-group to test became linear dependent during the case resampling step\n")
                     print.default(anova$nBoot - anova$n.bootsdone - 1, quote = FALSE, right = TRUE, na.print = "", ...) 
@@ -155,7 +154,7 @@ default.print.anova.manyglm <- function(x,
 
         if( substr(anova$resamp,1,1)!="n"){
               cat("Arguments:\n", "Test statistics calculated assuming", corname, 
-              "\nP-value calculated using", n.bootsdone, "resampling iterations via",       paste(anova$resamp,block.text,sep=""), "resampling (to account for correlation in testing.\n")
+              "\nP-value calculated using", n.bootsdone, "iterations via",       paste(anova$resamp,block.text,sep=""), "resampling.\n")
            if(sum(anova$nBoot - anova$n.bootsdone)>1){
               cat("\nNumber of iterations with skipped test statistic as the respective              variable/variable-group to test became linear dependent during the case resampling step\n")
               print.default(anova$nBoot - anova$n.bootsdone - 1, quote = FALSE, right = TRUE, na.print = "", ...)
